@@ -9,7 +9,7 @@ var modules =
     [ "Drawing functions", "group__fl__drawings.html", "group__fl__drawings" ],
     [ "Multithreading support functions", "group__fl__multithread.html", "group__fl__multithread" ],
     [ "Safe widget deletion support functions", "group__fl__del__widget.html", "group__fl__del__widget" ],
-    [ "Cairo support functions and classes", "group__group__cairo.html", "group__group__cairo" ],
+    [ "Cairo Support Functions and Classes", "group__group__cairo.html", "group__group__cairo" ],
     [ "Unicode and UTF-8 functions", "group__fl__unicode.html", "group__fl__unicode" ],
     [ "Mac OS X-specific symbols", "group__group__macosx.html", "group__group__macosx" ],
     [ "Common Dialogs classes and functions", "group__group__comdlg.html", "group__group__comdlg" ],
