@@ -1,6 +1,6 @@
 var NAVTREE =
 [
-  [ "FLTK 1.3.3", "index.html", [
+  [ "FLTK 1.3.4", "index.html", [
     [ "FLTK Programming Manual", "index.html", "index" ],
     [ "Todo List", "todo.html", null ],
     [ "Deprecated List", "deprecated.html", null ],
@@ -37,25 +37,25 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "Enumerations_8H.html",
-"Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3aa776cf3129e97140c88a062881a2d29a",
-"Fl__Return__Button_8H_source.html",
-"classFl__Browser__.html#ac54a04415069ec232db034c283476572",
-"classFl__File__Chooser.html#a13d55aea2af92464a98f396d679115d7",
-"classFl__Graphics__Driver.html#a5b4765a8040427f7586bff03b49e80ee",
-"classFl__Input__.html#a54d355077e57e9901a775ea968c39963",
-"classFl__Paged__Device.html#aea57eda0ffa5353c7e678a17675681d4a1a399f1a5fcf30ae2853a91bf0820428",
-"classFl__Preferences_1_1Node.html#ac7dada4e7b034b1cb6e7cfd1f6f60878",
-"classFl__System__Printer.html#a5e5cb0bc76f33899d12a32762151088a",
-"classFl__Text__Buffer.html#ad78c9dd21ff3fc04060114ddc1448803",
-"classFl__Timer.html",
-"classFl__Tree__Item.html#afa951d403d14800a3fcf22ec3df2a33f",
-"classFl__Widget.html#ab2b89e03832a172d7648dabe0910b038",
-"events.html#events_fl_dnd_enter",
-"functions_func_p.html",
-"group__fl__attributes.html#gae68ad6c3474fb71b3db5a44658b60b14",
-"group__fl__events.html#ga08ba811a19462788094768ed98798120",
-"intro.html#intro_visualcpp",
-"structFl__Preferences_1_1Entry.html#a2b051afa655fd1ed856599fd114a12cd"
+"Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3a7d2e5eb9247b1927ba5cc26dc82acaf3",
+"Fl__Multiline__Input_8H_source.html",
+"classFl__Browser.html#aeadc4b1c149e211228f0cfaaf9df929f",
+"classFl__FLTK__File__Chooser.html#a43c23e477b1fa42daf6753cc84b8f3de",
+"classFl__Graphics__Driver.html",
+"classFl__Image.html#a149cf9b29d743fdd6adb4dd441e9095d",
+"classFl__Native__File__Chooser.html#adcfb1c4830c3883c602343d2cfc44a73",
+"classFl__Preferences.html#a20b8a66cd9fda6f727e391847653c4df",
+"classFl__Slider.html#aeda9efe572a5151dca87b41ac98cd6e5",
+"classFl__Text__Buffer.html#a12bfe32020ca2221a98455265b36e096",
+"classFl__Text__Display.html#ad6288a3a93930c706c154ea065308c9d",
+"classFl__Tree__Item.html",
+"classFl__Value__Input.html#ae73dfcd7760e0f80dec4fecb9ad3d163",
+"classFl__Wizard.html#a684252500c11e66e110713a82f85390b",
+"fl__ask_8H.html#af2427850080f7b2ddc65f9a0f1e2067cadf3a64f31aaf6ba0c6b93a45da955feb",
+"glut.html#glut_description",
+"group__fl__drawings.html#ga6f6f1aea3b90a03c1714336e7aef349d",
+"group__fl__unicode.html#ga82c145ba77cf3a650e0a0eb2f40e9766",
+"structFl__Glut__StrokeChar.html#a270526ffef05a9d90fa321a972c80962"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
